<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class VerificationController extends Controller
{
    public function verifyRC(Request $request) {
        // Validate the input first
        $request->validate([
            'rc_number' => ['required', 'string', 'max:11']
        ]);

        // Send request to API
        $apiResponse = $this->sendApiRequest('https://uat.apiclub.in/api/v1/rc_info', [
            'vehicleId' => $request->input('rc_number')
        ]);

        // Handle the response or error
        if ($apiResponse && ($apiResponse["code"] == 200)) {
            return view('verifications.rc', [
                'apiResponse' => $apiResponse['response'],
            ]);
        } else {
            return $this->handleApiError($apiResponse ?: ["message"]);
        }
    }

    private function sendApiRequest($url, $data) {
        try {
            // Send POST request to the API
            $response = Http::withHeaders([
                'Referer' => 'docs.apiclub.in',
                'accept' => 'application/json',
                'content-type' => 'application/json',
                'x-api-key' => 'apclb_gThQHlhQ6nBB4RupYjOIwJnaa8a75d30', // Your API key here
            ])->post($url, $data);

            // Check if the API response is successful
            if ($response->successful()) {
                $response = $response->json(); // Return JSON response
                Log::info($response);
                return $response;
            } else {
                return null; // Return null in case of failure
            }
        } catch (\Exception $exception) {
            return null;
        }
    }

    private function handleApiError($message = 'Failed to fetch data from the API.') {
        return back()->withErrors(['api_error' => $message]);
    }

    public function sendAadharOTP(Request $request) {
        $request->validate([
            'aadhar_number' => ['required', 'string', 'size:12'] // Aadhaar should be exactly 12 digits
        ]);

        // Send POST request to the API to send OTP
        $apiResponse = $this->sendApiRequest('https://uat.apiclub.in/api/v1/aadhaar_v2/send_otp', [
            'aadhaar_no' => $request->input("aadhar_number"),
        ]);

        // Check if the API response is successful
        if ($apiResponse && ($apiResponse["code"] == 200)) {
            // Store the ref_id in session to be used when verifying OTP
            session(['ref_id' => $apiResponse['response']['ref_id']]);

            // Redirect to the page to enter the OTP
            return redirect()->route('aadhar.otp')->with('status',
                'OTP has been sent to your registered mobile number.');
        } else {
            return $this->handleApiError('Failed to send OTP. Please try again.');
        }
    }

    public function verifyAadharOTP(Request $request) {
        // Validate the OTP input
        $request->validate([
            'otp' => ['required', 'string', 'size:6'],
        ]);

        // Retrieve the ref_id from the session
        $ref_id = session('ref_id');
        if (!$ref_id) {
            return $this->handleApiError('Invalid OTP session. Please retry the Aadhaar verification process.');
        }

        // Send OTP verification request
        $apiResponse = $this->sendApiRequest('https://uat.apiclub.in/api/v1/aadhaar_v2/submit_otp', [
            'ref_id' => $ref_id,
            'otp' => $request->input('otp'),
        ]);

        // Handle the response or error
        if ($apiResponse) {
            return view('verifications.aadhar_success', [
                'aadharDetails' => $apiResponse['response']
            ]);
        } else {
            return $this->handleApiError('Failed to verify OTP. Please try again.');
        }
    }

    public function verifyDL(Request $request) {
        // Validate the input Driving License number
        $request->validate([
            'dl_number' => ['required', 'string', 'min:10']
        ]);

        // Send request to API
        $apiResponse = $this->sendApiRequest('https://uat.apiclub.in/api/v1/fetch_dl', [
            'license_number' => $request->input('dl_number')
        ]);

        // Handle the response or error
        if ($apiResponse && ($apiResponse["code"] == 200)) {
            return view('verifications.dl', [
                'dlDetails' => $apiResponse['response']
            ]);
        } else {
            return $this->handleApiError($apiResponse ?: ["message"]);
        }
    }

}
